Mixed-up Code Questions
-----------------------
.. selectquestion:: str-mixed-emotion-sq
   :fromid: str-mixed-emotion, str-mixed-emotion-ac
   :toggle:

.. selectquestion:: str-mixed-book-sq
   :fromid: str-mixed-book, str-mixed-book-ac
   :toggle:

.. selectquestion:: str-mixed-code-sq
   :fromid: str-mixed-code, str-mixed-code-ac
   :toggle:

.. selectquestion:: str-mixed-time-sq
   :fromid: str-mixed-time, str-mixed-time-ac
   :toggle:

.. selectquestion:: str-mixed-feeling-sq
   :fromid: str-mixed-feeling, str-mixed-feeling-ac
   :toggle:

.. selectquestion:: str-mixed-animal-sq
   :fromid: str-mixed-animal, str-mixed-animal-ac
   :toggle:

.. selectquestion:: str-mixed-add-sq
   :fromid: str-mixed-add, str-mixed-add-ac
   :toggle:

.. selectquestion:: str-mixed-wizard-sq
   :fromid: str-mixed-wizard, str-mixed-wizard-ac
   :toggle:

.. selectquestion:: str-mixed-colors-sq
   :fromid: str-mixed-colors, str-mixed-colors-ac
   :toggle:

.. selectquestion:: str-mixed-dogs-sq
   :fromid: str-mixed-dogs, str-mixed-dogs-ac
   :toggle:

